@@ -1,15 +1,12 @@
 extern crate daemonize_me;
-use daemonize_me::{Daemon, Group, User};
-use nix::unistd::{getgid, getuid};
-use std::convert::TryFrom;
+
 use std::fs::File;
 
+pub use daemonize_me::{Daemon, User, Group};
+
 fn main() {
     let stdout = File::create("info.log").unwrap();
     let stderr = File::create("err.log").unwrap();
-    let uid = getuid();
-    let gid = getgid();
-    println!("sid: {}, pid: {}", uid, gid);
     let daemon = Daemon::new()
         .pid_file("example.pid", Some(false))
         .user(User::try_from("daemon").unwrap())
@@ -24,7 +21,8 @@ fn main() {
         Ok(_) => println!("Daemonized with success"),
         Err(e) => eprintln!("Error, {}", e),
     }
-    // use infinite loop to keep process open for inspection
-    println!("Hello from the daemon");
-    loop {}
+
+    loop {
+        // You wil have to kill this process yourself
+    }
 }
